@@ -5,17 +5,18 @@
 
 import sys
 
-import pyptlib
-import pyptlib.server
+from pyptlib.server import ServerTransportPlugin
+from pyptlib.config import EnvError
 
 if __name__ == '__main__':
+    server = ServerTransportPlugin()
     try:
-        managed_info = pyptlib.server.init(["blackfish", "bluefish"])
-    except pyptlib.config.EnvError, err:
+        server.init(["blackfish", "bluefish"])
+    except EnvError, err:
         print "pyptlib could not bootstrap ('%s')." % str(err)
         sys.exit(1)
 
-    for transport, transport_bindaddr in managed_info['transports'].items():
+    for transport, transport_bindaddr in server.getBindAddresses().items():
         # Try to spawn transports and make them listen in the ports
         # that Tor wants. Report failure or success appropriately.
 
@@ -29,7 +30,7 @@ if __name__ == '__main__':
             reportFailure(transport, "Failed to launch ('%s')." % str(err))
             continue
 
-        pyptlib.server.reportSuccess(transport, bind_addrport, None)
+        server.reportMethodSuccess(transport, bind_addrport, None)
 
     # Report back after we finish spawning transports.
-    pyptlib.server.reportEnd()
+    server.reportMethodsEnd()
