@@ -10,6 +10,33 @@ import pyptlib.util as util
 
 from pyptlib.config import env_has_k, get_env, SUPPORTED_TRANSPORT_VERSIONS
 
+def get_transport_options_impl(string):
+    """
+    Parse transport options.
+    :param str optstring: Example input: 'scramblesuit:k=v;scramblesuit:k2=v2;obs3fs:k=v'
+    :returns: {'obfs3': {'k':'v'}, 'scramblesuit': {'k2' : 'v2', 'k' : 'v'} }
+    """
+    transport_args = {}
+
+    params = string.split(';')
+    for param in params:
+        try:
+            (name, kv_string) = param.split(':')
+        except ValueError:
+            raise ValueError("Invalid options string (%s)" % param)
+
+        if name not in transport_args:
+            transport_args[name] = {}
+
+        try:
+            (key, value) = kv_string.split('=')
+        except ValueError:
+            raise ValueError("Not a k=v value (%s)" % kv_string)
+
+        transport_args[name][key] = value
+
+    return transport_args
+
 class ServerConfig(config.Config):
     """
     A client-side pyptlib configuration.
@@ -18,6 +45,8 @@ class ServerConfig(config.Config):
     :var tuple extendedORPort: (ip,port) pointing to Tor's Extended ORPort. None if Extended ORPort is not supported.
     :var dict serverBindAddr: A dictionary {<transport> : [<addr>, <port>]}, where <transport> is the name of the transport that must be spawned, and [<addr>, <port>] is a list containing the location where that transport should bind. The dictionary can be empty.
     :var string authCookieFile: String representing the filesystem path where the Extended ORPort Authentication cookie is stored. None if Extended ORPort authentication is not supported.
+    :var dict serverTransportOptions: Dictionary containing user-provided parameters that must be passed to the pluggable transports.
+        Example: {'obfs3': {'k':'v'}, 'scramblesuit': {'k2' : 'v2', 'k' : 'v'} }
     """
 
     @classmethod
@@ -40,20 +69,20 @@ class ServerConfig(config.Config):
         # Check that either both Extended ORPort and the Extended
         # ORPort Authentication Cookie are present, or neither.
         if extendedORPort:
-            def validate_authcookie(_, v):
+            def get_authcookie(_, v):
                 if v is None: raise ValueError("Extended ORPort address provided, but no cookie file.")
                 return v
         else:
-            def validate_authcookie(_, v):
+            def get_authcookie(_, v):
                 if v is not None: raise ValueError("Extended ORPort Authentication cookie file provided, but no Extended ORPort address.")
                 return v
-        authCookieFile = get_env('TOR_PT_AUTH_COOKIE_FILE', validate_authcookie)
+        authCookieFile = get_env('TOR_PT_AUTH_COOKIE_FILE', get_authcookie)
 
         # Get ORPort.
         ORPort = get_env('TOR_PT_ORPORT', empty_or_valid_addr)
 
         # Get bind addresses.
-        def validate_server_bindaddr(k, bindaddrs):
+        def get_server_bindaddr(k, bindaddrs):
             serverBindAddr = {}
             bindaddrs = env_has_k(k, bindaddrs).split(',')
             for bindaddr in bindaddrs:
@@ -61,17 +90,24 @@ class ServerConfig(config.Config):
                 (addr, port) = util.parse_addr_spec(addrport)
                 serverBindAddr[transport_name] = (addr, port)
             return serverBindAddr
-        serverBindAddr = get_env('TOR_PT_SERVER_BINDADDR', validate_server_bindaddr)
+        serverBindAddr = get_env('TOR_PT_SERVER_BINDADDR', get_server_bindaddr)
 
         # Get transports.
-        def validate_transports(k, transports):
+        def get_transports(k, transports):
             transports = env_has_k(k, transports).split(',')
             t = sorted(transports)
             b = sorted(serverBindAddr.keys())
             if t != b:
                 raise ValueError("Can't match transports with bind addresses (%s, %s)" % (t, b))
             return transports
-        transports = get_env('TOR_PT_SERVER_TRANSPORTS', validate_transports)
+        transports = get_env('TOR_PT_SERVER_TRANSPORTS', get_transports)
+
+        def get_transport_options(k, v):
+            if v is None:
+                return None
+            serverTransportOptions = env_has_k(k, v)
+            return get_transport_options_impl(serverTransportOptions)
+        transport_options = get_env('TOR_PT_SERVER_TRANSPORT_OPTIONS', get_transport_options)
 
         return cls(
             stateLocation = get_env('TOR_PT_STATE_LOCATION'),
@@ -80,7 +116,8 @@ class ServerConfig(config.Config):
             serverBindAddr = serverBindAddr,
             ORPort = ORPort,
             extendedORPort = extendedORPort,
-            authCookieFile = authCookieFile
+            authCookieFile = authCookieFile,
+            serverTransportOptions = transport_options
             )
 
     def __init__(self, stateLocation,
@@ -89,7 +126,8 @@ class ServerConfig(config.Config):
                  serverBindAddr=None,
                  ORPort=None,
                  extendedORPort=None,
-                 authCookieFile=None):
+                 authCookieFile=None,
+                 serverTransportOptions=None):
         config.Config.__init__(self, stateLocation,
             managedTransportVer or SUPPORTED_TRANSPORT_VERSIONS,
             transports or [])
@@ -97,6 +135,7 @@ class ServerConfig(config.Config):
         self.ORPort = ORPort
         self.extendedORPort = extendedORPort
         self.authCookieFile = authCookieFile
+        self.serverTransportOptions = serverTransportOptions
 
     def getExtendedORPort(self):
         """
@@ -115,3 +154,9 @@ class ServerConfig(config.Config):
         :returns: :attr:`pyptlib.server_config.ServerConfig.authCookieFile`
         """
         return self.authCookieFile
+
+    def getServerTransportOptions(self):
+        """
+        :returns: :attr:`pyptlib.server_config.ServerConfig.serverTransportOptions`
+        """
+        return self.serverTransportOptions
